#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-test
version:              2.13.1.3
visibility:           public
id:                   persistent-test-2.13.1.3-K6Wq9tL0PSu7IUBh3hwSjZ
key:                  persistent-test-2.13.1.3-K6Wq9tL0PSu7IUBh3hwSjZ
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Tests for Persistent
description:
    Tests for Persistent. This is only for use in developing libraries that should conform to the persistent interface, not for users of the persistent suite of database libraries.

category:             Database, Yesod
abi:                  4002d4cf15bc3d1d0e6795323548b6f4
exposed:              True
exposed-modules:
    CompositeTest CustomPersistField CustomPersistFieldTest
    CustomPrimaryKeyReferenceTest DataTypeTest EmbedOrderTest EmbedTest
    EmptyEntityTest EntityEmbedTest EquivalentTypeTest ForeignKey
    GeneratedColumnTestSQL HtmlTest Init LargeNumberTest
    LongIdentifierTest MaxLenTest MaybeFieldDefsTest
    MigrationColumnLengthTest MigrationIdempotencyTest
    MigrationOnlyTest MigrationTest MpsCustomPrefixTest MpsNoPrefixTest
    PersistTestPetCollarType PersistTestPetType PersistUniqueTest
    PersistentTest PersistentTestModels PersistentTestModelsImports
    PrimaryTest RawSqlTest ReadWriteTest Recursive RenameTest
    SumTypeTest TransactionLevelTest TreeTest TypeLitFieldDefsTest
    UniqueTest UpsertTest

import-dirs:          /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-test
hs-libraries:         HSpersistent-test-2.13.1.3-K6Wq9tL0PSu7IUBh3hwSjZ
depends:
    HUnit-1.6.2.0-DydRkK1Ty562EFYgxreweA
    QuickCheck-2.15.0.1-GIIsjuuZeTD5REN3cOn4Nc
    aeson-2.2.2.0-JRwGfw4G4faAdkvjZDffZf base-4.18.2.1
    blaze-html-0.9.2.0-B4Hv5HZA3X781LI0M8ZR92 bytestring-0.11.5.3
    conduit-1.3.6.1-5N1D7XReUYC7Q0FFK7LvDS containers-0.6.7
    exceptions-0.10.7 hspec-2.11.7-7gnoQNyRayg3C2dCwMP172
    hspec-expectations-0.8.4-JRz47SURfXgGxfIuVeuxEa
    http-api-data-0.6.1-JS3AyagWAbIFbbYJuAGbBd
    monad-control-1.0.3.1-FKQevUTXtN116pyhgQjb7S
    monad-logger-0.3.42-3nVlKNzk3w057XNmXXteXi mtl-2.3.1
    path-pieces-0.2.1-ILPSumWqTsA51OyVDS7ISl
    persistent-2.14.6.0-9O6Or4QIlw84QWgPl806Vx
    quickcheck-instances-0.3.33-1FePwfH9Y2dJRxxqcMEPc3
    random-1.2.1.3-HWePNsfMjqy9mivdeOZEPQ
    resourcet-1.3.0-NkgSS2nOUY5UPO0Rt6LWs text-2.0.2 time-1.12.2
    transformers-0.6.1.0
    transformers-base-0.4.6.1-EowEPFXpidE8xEZyuLxn93
    unliftio-0.2.25.1-wbCzY6GGN1Jjb0ZnqHZMi
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.21-8pZ5d13ZaJk3LfHcqeQHmo

haddock-interfaces:
    /usr/share/doc/haskell-persistent-test/html/persistent-test.haddock

haddock-html:         /usr/share/doc/haskell-persistent-test/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

